@@ -11,49 +11,47 @@ class NumpyEncoder(JSONEncoder):
         return JSONEncoder.default(self, obj)
 
 
-from fastapi import FastAPI, Request, Body
-from fastapi.responses import Response
+from sanic import Sanic
+from sanic import response
 from pydantic import schema_of
 import importlib
-import uvicorn
 from typing import Any
 
-app = FastAPI()
+app = Sanic(name="abottle")
 
 USERMODEL = None
 
 
 @app.post("/predict")
-async def predict(request: Request, X: typing.Any = Body(...)):
-    user_request = await request.json()
+async def predict(request):
     # FIXME: should comprese resposne content
-    user_response = USERMODEL.predict(**user_request)
+    user_response = USERMODEL.predict(**request.json)
     response_content = json.dumps(user_response, cls=NumpyEncoder)
     # log here
-    return Response(content=response_content, media_type="application/json")
+    return response.text(content=response_content, media_type="application/json")
 
 
 @app.post("/metrics")
-async def metrics():
+async def metrics(request):
     raise NotImplementedError()
 
 
 @app.get("/healthz")
-async def healthz():
+async def healthz(request):
     if hasattr(USERMODEL, "status"):
         return USERMODEL.status()
-    return True
+    return response.text(True)
 
 
 @app.get("/readyz")
-async def readyz():
+async def readyz(request):
     if hasattr(USERMODEL, "status"):
         return USERMODEL.status()
-    return True
+    return response.text(True)
 
 
 @app.get("/meta")
-async def meta():
+async def meta(request):
     if hasattr(USERMODEL, "meta"):
         user_meta = USERMODEL.meta()
         if user_meta:
@@ -62,7 +60,7 @@ async def meta():
     user_meta_dict = {}
     for key in user_meta:
         user_meta_dict[key] = schema_of(user_meta[key], title=key)
-    return user_meta_dict
+    return response.json(user_meta_dict)
 
 
 from pathlib import Path
@@ -141,8 +139,12 @@ def load(usermodel_name, wrapper, config=None, *args, **kwargs):
     return usermodel
 
 
-def start_server(host, port):
-    uvicorn.run(app, host=host, port=port)
+import os
+
+
+def start_server(**kwargs):
+    kwargs["workers"] = os.cpu_count() * 2 - 1
+    app.run(**kwargs)
 
 
 def run_tester(**kwargs):
@@ -187,7 +189,7 @@ def main():
     USERMODEL = load(**vars(args))
 
     if args.as_ == "server":
-        start_server(args.host, args.port)
+        start_server(host=args.host, port=args.port)
     if args.as_ == "tester":
         tester_args = {}
         for unknown in unknowns:
